==> istio-model-v1beta1-5.12.1-sources.jar: io/fabric8/istio/api/security/v1beta1/OperationBuilder.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperationBuilder extends io.fabric8.istio.api.security.v1beta1.OperationFluentImpl<io.fabric8.istio.api.security.v1beta1.OperationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.security.v1beta1.Operation,io.fabric8.istio.api.security.v1beta1.OperationBuilder>{
  public OperationBuilder() {
    this(false);
  }
  public OperationBuilder(java.lang.Boolean validationEnabled) {
    this(new Operation(), validationEnabled);
  }
  public OperationBuilder(io.fabric8.istio.api.security.v1beta1.OperationFluent<?> fluent) {
    this(fluent, false);
  }
  public OperationBuilder(io.fabric8.istio.api.security.v1beta1.OperationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Operation(), validationEnabled);
  }
  public OperationBuilder(io.fabric8.istio.api.security.v1beta1.OperationFluent<?> fluent,io.fabric8.istio.api.security.v1beta1.Operation instance) {
    this(fluent, instance, false);
  }
  public OperationBuilder(io.fabric8.istio.api.security.v1beta1.OperationFluent<?> fluent,io.fabric8.istio.api.security.v1beta1.Operation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHosts(instance.getHosts()); 
    fluent.withMethods(instance.getMethods()); 
    fluent.withNotHosts(instance.getNotHosts()); 
    fluent.withNotMethods(instance.getNotMethods()); 
    fluent.withNotPaths(instance.getNotPaths()); 
    fluent.withNotPorts(instance.getNotPorts()); 
    fluent.withPaths(instance.getPaths()); 
    fluent.withPorts(instance.getPorts()); 
    this.validationEnabled = validationEnabled; 
  }
  public OperationBuilder(io.fabric8.istio.api.security.v1beta1.Operation instance) {
    this(instance,false);
  }
  public OperationBuilder(io.fabric8.istio.api.security.v1beta1.Operation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHosts(instance.getHosts()); 
    this.withMethods(instance.getMethods()); 
    this.withNotHosts(instance.getNotHosts()); 
    this.withNotMethods(instance.getNotMethods()); 
    this.withNotPaths(instance.getNotPaths()); 
    this.withNotPorts(instance.getNotPorts()); 
    this.withPaths(instance.getPaths()); 
    this.withPorts(instance.getPorts()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.security.v1beta1.OperationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.security.v1beta1.Operation build() {
    Operation buildable = new Operation(fluent.getHosts(),fluent.getMethods(),fluent.getNotHosts(),fluent.getNotMethods(),fluent.getNotPaths(),fluent.getNotPorts(),fluent.getPaths(),fluent.getPorts());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperationBuilder that = (OperationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/security/v1beta1/OperationBuilder.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OperationBuilder extends OperationFluentImpl<OperationBuilder> implements VisitableBuilder<Operation,OperationBuilder>{
  public OperationBuilder() {
    this(false);
  }
  public OperationBuilder(Boolean validationEnabled) {
    this(new Operation(), validationEnabled);
  }
  public OperationBuilder(OperationFluent<?> fluent) {
    this(fluent, false);
  }
  public OperationBuilder(OperationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Operation(), validationEnabled);
  }
  public OperationBuilder(OperationFluent<?> fluent,Operation instance) {
    this(fluent, instance, false);
  }
  public OperationBuilder(OperationFluent<?> fluent,Operation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHosts(instance.getHosts()); 
    fluent.withMethods(instance.getMethods()); 
    fluent.withNotHosts(instance.getNotHosts()); 
    fluent.withNotMethods(instance.getNotMethods()); 
    fluent.withNotPaths(instance.getNotPaths()); 
    fluent.withNotPorts(instance.getNotPorts()); 
    fluent.withPaths(instance.getPaths()); 
    fluent.withPorts(instance.getPorts()); 
    this.validationEnabled = validationEnabled; 
  }
  public OperationBuilder(Operation instance) {
    this(instance,false);
  }
  public OperationBuilder(Operation instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withHosts(instance.getHosts()); 
    this.withMethods(instance.getMethods()); 
    this.withNotHosts(instance.getNotHosts()); 
    this.withNotMethods(instance.getNotMethods()); 
    this.withNotPaths(instance.getNotPaths()); 
    this.withNotPorts(instance.getNotPorts()); 
    this.withPaths(instance.getPaths()); 
    this.withPorts(instance.getPorts()); 
    this.validationEnabled = validationEnabled; 
  }
  OperationFluent<?> fluent;
  Boolean validationEnabled;
  public Operation build() {
    Operation buildable = new Operation(fluent.getHosts(),fluent.getMethods(),fluent.getNotHosts(),fluent.getNotMethods(),fluent.getNotPaths(),fluent.getNotPorts(),fluent.getPaths(),fluent.getPorts());
    return buildable;
  }
  
}
